@@ -888,7 +888,7 @@ void auto2_read_repo_files(url_t *url)
 
   if(config.url.autoyast) {
     if(
-      config.url.autoyast->scheme == inst_rel &&
+      config.url.autoyast->is.relative &&
       config.autoyast_parse
     ) {
       log_show_maybe(!config.url.autoyast->quiet, "AutoYaST file in repo: %s\n", url_print(config.url.autoyast, 5));
@@ -908,9 +908,12 @@ void auto2_read_repo_files(url_t *url)
     if(util_check_exist("/tmp/autoinst.xml")) rename("/tmp/autoinst.xml", "/autoinst.xml");
 
     if(util_check_exist("/autoinst.xml")) {
-      log_info("setting AutoYaST option to file:/autoinst.xml\n");
-      url_free(config.url.autoyast);
-      config.url.autoyast = url_set("file:/autoinst.xml");
+      // with repo scheme, pass the the original URL to yast
+      if(config.url.autoyast->scheme != inst_repo) {
+        log_info("setting AutoYaST option to file:/autoinst.xml\n");
+        url_free(config.url.autoyast);
+        config.url.autoyast = url_set("file:/autoinst.xml");
+      }
       // parse for embedded linuxrc options in <info_file> element
       log_info("parsing AutoYaST file\n");
       file_read_info_file("file:/autoinst.xml", kf_cfg);
@@ -1095,7 +1098,7 @@ int auto2_add_extension(char *extension)
     err = 1;
   }
 
-  if(config.url.instsys->scheme == inst_rel && !config.url.install) {
+  if(config.url.instsys->is.relative && !config.url.install) {
     log_info("no repo\n");
     err = 2;
   }
@@ -1107,7 +1110,7 @@ int auto2_add_extension(char *extension)
 
   strprintf(&config.url.instsys->path, "%s/%s", s, extension);
 
-  if(config.url.instsys->scheme == inst_rel) {
+  if(config.url.instsys->is.relative) {
     err = url_find_repo(config.url.install, config.mountpoint.instdata);
   }
 
@@ -1227,7 +1230,7 @@ void auto2_read_autoyast(url_t *url)
   if(!url) return;
 
   // rel url is taken care of in auto2_read_repo_files()
-  if(url->scheme == inst_rel) return;
+  if(url->is.relative) return;
 
   /*
    * If the AutoYaST url is a directory we have to verify its existence
